@@ -35,11 +35,24 @@ our @EXPORT_OK;
 use List::Util qw(max maxstr min minstr);
 use Math::Trig;
 
-=for 
-    getcoords 
+=head1 NAME
+
+GeometricMeasurements
+
+=head1 VERSION
+
+Version 0.01
+
+=cut
+
+our $VERSION = '0.01';
+
+=head2 getcoords 
+
     This subroutine gets the coordinates of a given type of atom from the PDB file
     
     my @ca = getcoords( \@idtable, \@lm, 'CA', $ArrayRef_coordchain);   
+
 =cut
 sub getcoords {
 
