@@ -86,7 +86,7 @@ my $host = "";
 
 =head1 NAME
 
-GeometricalCalculations - The great new GeometricalCalculations!
+GeometricalCalculations
 
 =head1 VERSION
 
@@ -99,29 +99,14 @@ our $VERSION = '0.01';
 
 =head1 SYNOPSIS
 
-Quick summary of what the module does.
-
-Perhaps a little code snippet.
-
-    use GeometricalCalculations;
-
-    my $foo = GeometricalCalculations->new();
-    ...
-
-=head1 EXPORT
-
-A list of functions that can be exported.  You can delete this section
-if you don't export anything, such as for a purely object-oriented module.
-
-=head1 SUBROUTINES/METHODS
-
-
+This module consists of all subroutines that carry out geometrical calculations
+using the atomic coordinates obtained from a protein structure. 
 
 =head2 calc_geom 
 	
 	subroutine  to calculate delta, theta, and rho angles for an smotif
 	
-        Input 1: $lvec - vector between the anchor points of the bracing secondary structures
+    Input 1: $lvec - vector between the anchor points of the bracing secondary structures
 	Input 2: $e1 - axis vector for 1st secondary structure
 	Input 3: $e2 - axis vector for 2nd secondary structure
 
