@@ -38,6 +38,26 @@ BEGIN {
 
 our @EXPORT_OK;
 
+=head1 NAME
+
+GetSMotifsfromPDB
+
+=head1 VERSION
+
+Version 0.01
+
+=cut
+
+our $VERSION = '0.01';
+
+
+=head1 SYNOPSIS
+
+This module consists of subroutines that identify the Smotifs in a given 
+PDB file (required for the creation of the dynamic Smotif library). 
+
+=cut
+
 # our ($PDB_DIR, $PDB_OBSOLETES);
 our $PDB_DIR;
 our $PDB_OBSOLETES;
