@@ -18,6 +18,10 @@ Protein Class
 
 Version 0.01
 
+=cut
+
+our $VERSION = '0.01';
+
 =head1 SYNOPSIS
 
 This package contains the 'Protein' class used to represent a protein 
@@ -26,7 +30,7 @@ constructing, modifying, and evaluating the given protein structure
 
     use Protein;
 
-    my $foo = Protein->new();
+    my $test = Protein->new();
     ...
 
 =head2 new
